@@ -51,7 +51,7 @@ class RestApplication(object):
 
             response = e
 
-            self.process_response_hooks(response, response)
+            self.process_response_hooks(request, response)
 
             return response
 
@@ -67,11 +67,11 @@ class RestApplication(object):
 
             Endpoint, kwargs = urls.match()
 
-        except NotFound as e:
+        except HTTPException as e:
 
             response = e
 
-            self.process_response_hooks(response, response)
+            self.process_response_hooks(request, response)
 
             return response
 
